#
# spec file for package infiniband-diags
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define ibnetdisc_major 5
%define mad_major 5
%define git_ver .0.16dfa80c8566

Name:           infiniband-diags
Summary:        OpenFabrics Alliance InfiniBand Diagnostic Tools
License:        GPL-2.0-only OR BSD-2-Clause
Group:          Productivity/Networking/Diagnostic
Version:        2.1.0
Release:        5.31
Source0:        %{name}-%{version}%{git_ver}.tar.gz
Source1:        baselibs.conf
Patch2:         infiniband-diags-help_for_ibnodes.patch
Url:            http://www.openfabrics.org
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  glib2-devel
BuildRequires:  libtool
BuildRequires:  opensm-devel
BuildRequires:  pkg-config
BuildRequires:  rdma-core-devel
BuildRequires:  systemd-rpm-macros
BuildRequires:  pkgconfig(libudev)
Requires:       perl = %{perl_version}

%description
diags provides IB diagnostic programs and scripts needed to diagnose an
IB subnet.

%package    -n libibnetdisc%{ibnetdisc_major}
Summary:        Infiniband Net Discovery runtime library
Group:          System/Libraries

%description -n libibnetdisc%{ibnetdisc_major}
This package contains the Infiniband Net Discovery runtime library needed
mainly by infiniband-diags.


%package        devel
Summary:        OpenIB InfiniBand Diagnostic Tools SDK
Group:          Development/Libraries/C and C++
BuildRequires:  opensm-devel
BuildRequires:  rdma-core-devel
Requires:       %{name} = %{version}
Requires:       libibmad%{mad_major} = %version
Requires:       libibnetdisc%{ibnetdisc_major} = %version
Provides:       infiniband-diags:%{_libdir}/libibnetdisc.so
Provides:       libibmad-devel = %{version}-%{release}
Obsoletes:      libibmad-devel < %{version}

%description    devel
diags provides IB diagnostic programs and scripts needed to diagnose an
IB subnet. This package contains all files needed for development.

%package -n     libibmad%{mad_major}
Summary:        Libibamd runtime library
Group:          System/Libraries
BuildRequires:  rdma-core-devel

%description -n libibmad%{mad_major}
Libibmad provides low layer IB functions for use by the IB diagnostic
and management programs. These include MAD, SA, SMP, and other basic IB
functions. This package contains the runtime library.

%prep
%setup -q -n  %{name}-%{version}%{git_ver}
# rename to silence automake
%patch2

# Avoid unnecessary rebuilds of the package
FAKE_BUILDDATE=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%b %%e %%Y')
FAKE_BUILDTIME=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%H:%%M:%%S')
sed -i -e "s/__DATE__/\"$FAKE_BUILDDATE\"/" -e "s/__TIME__/\"$FAKE_BUILDTIME\"/" src/ibdiag_common.c

%build
autoreconf -fi
export CFLAGS="%{optflags}"
%configure --with-perl-installdir=%{perl_vendorarch} --disable-static
make %{?_smp_mflags} V=1

%install
make DESTDIR=%buildroot install
rm -f %{buildroot}%{_libdir}/*.la

%check
make check

%post -n libibnetdisc%{ibnetdisc_major} -p /sbin/ldconfig
%postun -n libibnetdisc%{ibnetdisc_major} -p /sbin/ldconfig

%post -n libibmad%{mad_major} -p /sbin/ldconfig
%postun -n libibmad%{mad_major} -p /sbin/ldconfig

%files
%defattr(-, root, root)
%doc COPYING README ChangeLog
%config %{_sysconfdir}/infiniband-diags/error_thresholds
%dir %{_sysconfdir}/infiniband-diags
%config(noreplace) %{_sysconfdir}/infiniband-diags/*
%_sbindir/*
%_mandir/man8/*
%_mandir/man3/*
%{perl_vendorarch}/IBswcountlimits.pm

%files -n libibnetdisc%{ibnetdisc_major}
%defattr(-, root, root)
%{_libdir}/libibnetdisc.so.*

%files -n libibmad%{mad_major}
%defattr(-, root, root)
%doc COPYING
%_libdir/libibmad.so.*

%files devel
%defattr(-, root, root)
%{_includedir}/infiniband/*.h
%{_libdir}/*.so

%changelog
* Wed Aug  8 2018 nmoreychaisemartin@suse.com
- Update to version 2.1.0
  * New device IDs
  * Add file of ports pairs in ibtracert
  * ibqueryerrors additional counters
  * HDR support
  * Bug Fixes
* Tue Sep  5 2017 nmoreychaisemartin@suse.com
- Update _service to allow auto updates from github
* Thu Jun 22 2017 nmoreychaisemartin@suse.com
- infiniband-diags-devel obsoletes old libibmad-devel
  to fix conflicts
* Fri Jun 16 2017 nmoreychaisemartin@suse.com
- Updated to version 2.0.0 (fate#323533)
  * No short changelog available; please read the ChangeLog file
- rdma-ndd was removed from infiniband-diags (now in rdma-core)
- libibmad is now part of infiniband-diags
- Remove obsolete infiniband-diags-rpmlintrc
- Add _service to fetch from upstream repo
- Add baselibs.conf for libibnetdisc and libibmad
* Mon May 15 2017 nmoreychaisemartin@suse.com
- Remove rdma-ndd now provided by the rdma-core package (bsc#1039146).
* Wed May 10 2017 nmoreychaisemartin@suse.com
- Update to version 1.6.7 (fate#321867)
  * No short changelog available; please read the ChangeLog file
- Use packaged rdma-ndd service file
- Unify spec and patches with SLE12
* Mon Mar  7 2016 pth@suse.de
- Update to latest git version (fate#320027).
  For changes see the included ChangeLog.
- Include Changelog.
- Remove infiniband-diags-automake_foreign.patch and
  infiniband-diags-configure.patch as they aren't needed anymore.
- New sub package rdma-ndd, needed for the above fate.
* Tue Nov  3 2015 p.drouand@gmail.com
- Update to version 1.6.6
  * No short changelog available; please read the ChangeLog file
- Use download Url as source
- Add a systemd service file for rdma-ndd
- Add pkgconfig(libudev) and systemd-rpm-macros build require
- Add dependency to systemd
- Update infiniband-diags-configure.patch
* Mon Nov 17 2014 ledest@gmail.com
- fix bashism in ibnodes script
- update patches:
  * infiniband-diags-help_for_ibnodes.patch
* Fri Jul  4 2014 pth@suse.de
- Do not build and package static libraries.
- Package a rpmlintrc to block the bogus warnings about files
  containing date and time.
* Tue Jun  3 2014 pth@suse.de
- Update to OFED 3.12 final.
* Tue Feb 18 2014 pth@suse.de
- 1.6.4 uses configure.ac so remove the now bogus rename.
* Thu Feb 13 2014 pth@suse.de
- Update to 1.6.4 for fate#315488. Changes since 1.6.2 :
  * Revert "libibnetdisc/ibnetdisc.c: improve log information to stdout"
  * ibtracert.8.in: change default pre-built man page
  * infiniband-diags: Check node-name-map strings when querying by name
  * libibnetdisc/ibnetdisc.c: improve log information to stdout
  * libibnetdisc/ibnetdisc.c: fix insert of invalid lid 0xFFFF into
    lid_port hash_table
  * ibtracert.c: Add 'force' flag to man page
  * infiniband-diags/vendstat: Fix GeneralInfo SW version
  * ibportstate: on/off option is missing in help
  * iblinkinfo: Remove "-R" option from man page
  * ibaddr: Add missing -t option to manpage
  * ibdiag_sa.c: Output attribute ID in hex rather than decimal
  * get_lid_from_name(): Remove an unused variable
- Rename configure.in to configure.ac to shut up autoconf.
* Wed Jan 29 2014 pth@suse.de
- Change License to GPL-2.0 or BSD-3-Clause.
- Add COPYING to package.
* Tue Jan 21 2014 pth@suse.de
- Update to 1.6.2 from OFED 3.12 daily
- Fix configure.ac
- Add glib2-devel to BuildRequires as libibnetdisc needs it.
* Wed Jan 15 2014 pth@suse.de
- Enable build for s390x.
* Mon Feb 25 2013 pth@suse.de
- Make ibnodes output its own help (bnc#740144):
  infiniband-diags-help_for_ibnodes.patch
* Thu Sep 13 2012 pth@suse.de
- Make the package own /etc/infiniband-diags
- Use timestamp of .changes file as __DATE__ and __TIME__ to
  avoid unnecessary rebuilds.
* Mon Sep  3 2012 pth@suse.de
- Update to 1.5.13 from OFED 1.5.4.1
* Fri Jul 20 2012 pth@suse.de
- Update to 1.5.12 from OFED 1.5.4.
* Tue May  8 2012 pth@suse.de
- BuildRequire automake, autoconf and libtool.
* Fri Jan 28 2011 pth@suse.de
- Provide split provides for update.
* Fri Oct 29 2010 stefan.fent@novell.com
- correct requires to libibumad-devel
- split *-devel package
* Wed Oct 27 2010 jjolly@novell.com
- Many changes to the %%files section
* Mon Oct 25 2010 jjolly@novell.com
- Update to v1.5.7 from OFED 1.5.2
* Sat Mar 20 2010 jjolly@suse.de
- Update to v1.4.4_20090314 from OFED 1.4.2
* Thu Dec 11 2008 jjolly@suse.de
- Updated to v1.4.4_20081207 from OFED 1.4 GA
  - infiniband-diags/grouping: add 10G IP router devid
  - infiniband-diags/ibstat.c: Use UMAD_MAX_DEVICES define
  - infiniband-diags/ibstat.c: remove casting
  - Fix max parameter passed to umad_get_cas_names
  - infiniband-diags/saquery.8: Update saquery man page
  - infiniband-diags/saquery: Support MFTRecord
  - infiniband-diags/saquery: add LFT Record handling
  - infiniband-diags/perfquery: fix constant size warning
  - infiniband-diags/perfquery: if -a is specified loop through
    ports if required and aggregate output
  - perfquery code cleanup
  - infiniband-diags/perfquery: if --loop_ports is specified always
    loop through all ports if desired
  - infinibanf-diags/perfquery: remove single port CA AllPortSelect
    workaround
  - infiniband-diags/perfquery: error out if AllPortSelect is not
    supported
  - tweak notes about port 255 in perfquery manpage
  - infiniband-diags/ibclearerrors: specify -a in call to perfquery
  - infiniband-diags/perfquery: support ehanced port 0 with
  - -loop-ports
  - infiniband-diags/ibsysstat.c: Fix a couple of latent bugs
  - add --loop_ports option to perfquery
  - add more detail to error message on perfquery workaround
  - use 0xff vs. 255 consistently in perfquery
  - add clarification in perfquery manpage
  - infiniband-diags: eliminate compiler warnings
  - infiniband-diags/ibtracert: fix port by direct path resolving
  - man/ibtracert: remove non-existing -e option
  - infiniband-diags/ibclearcounters: remove unrelated -N option
  - man/ibnetdiscover: cleanup non-existing options
  - ibnetdiscover.c: continue processing other ports even if
    smpquery fails on one port
  - Fix some missing node name map substitutions
  - infiniband-diags/src/ibaddr.c: remove unused variables
  - infiniband-diags/src/ibaddr.c: convert GID prints to use
    inet_ntop
  - infiniband-diags/saquery: remove unused variable
  - infiniband-diags/src/saquery.c: convert GID prints to use
    inet_ntop
* Thu Nov 13 2008 ro@suse.de
- excludearch s390 s390x
* Mon Oct 27 2008 jjolly@suse.de
- Updated to version from the OFED 1.4 rc3
* Thu Sep 11 2008 jjolly@suse.de
- Updated to 1.4.1 from the OFED 1.4 RC1
* Tue Mar  4 2008 jjolly@suse.de
- Update to 1.3.6 from the OFED 1.3 GA release
* Wed Feb 13 2008 pth@suse.de
- Run autoreconf
- Pass [foreign] to AM_INIT_AUTOMAKE
- Default for IBPATH is substituted by configure, no need to patch it.
- Update to 1.3.5.
  Changes since 1.2.7 are to numerous to list here, see NEWS and
  ChangeLog for the complete list.
* Mon Aug 20 2007 hvogel@suse.de
- Updated to version from OFED 1.2.5
* Thu Jul 19 2007 hvogel@suse.de
- fix path in the shellscripts
* Wed Jul  4 2007 hvogel@suse.de
- Add GPL COPYING file [#288855]
* Tue Jul  3 2007 hvogel@suse.de
- Downgrade to 1.2.7 because this turned out to be the version
  in OFED 1.2
* Wed Jun 20 2007 hvogel@suse.de
- Initial Package, Version 1.3.0
